@@ -4,6 +4,14 @@ from collections.abc import Mapping, Sequence
 
 
 class Headers:
+    """Headers implementation for handling :class:`str` or :class:`bytes`
+    names and values.
+
+    .. tip::
+        Use :func:`make_headers` to easily make a header from a :class:`list` or
+        a :class:`dict`.
+    """
+
     def __init__(self, *args, **kwargs):
         self._headers: typing.Dict[str, str] = {}
 
@@ -15,17 +23,60 @@ class Headers:
             self._headers[name.lower()] = value
 
     def get(self, name, default=None):
+        """Gets a header from its name. If not found, returns ``default``.
+
+        Parameters
+        ----------
+            name: :class:`str` or :class:`bytes`
+                Name of the header to get.
+            default: Optional anything
+                Value to return if header not found.
+                Default: ``None``
+
+        Returns
+        -------
+            :class:`str`
+                Header value if found.
+            Anything
+                ``default``'s value.
+        """
+
         if isinstance(name, bytes):
             name = name.decode("ascii")
         return self._headers.get(name.lower(), default)
 
     def keys(self):
+        """Returns an iterator over the headers names.
+
+        Returns
+        -------
+            Iterator of :class:`str`
+                Iterator over the headers names.
+        """
+
         return self._headers.keys()
 
     def items(self):
+        """Returns an iterator over the headers names and values.
+
+        Returns
+        -------
+            Iterator of ``(name, value)`` :class:`tuple`
+                Iterator over the headers names and values.
+        """
+
         return self._headers.items()
 
     def raw(self):
+        """Returns the raw headers, a :class:`list` of ``[name, value]`` where
+        ``name`` and ``value`` are :class:`bytes`.
+
+        Returns
+        -------
+            :class:`list` of ``[name, value]`` where ``name`` and ``value`` are\
+            :class:`bytes`
+                Raw headers for the ASGI response.
+        """
         return [
             [name.encode("ascii"), value.encode("ascii")]
             for name, value in self
@@ -102,10 +153,8 @@ def make_headers(headers=None) -> Headers:
         headers = Headers()
     elif isinstance(headers, Sequence):
         headers = Headers(*headers)
-    elif isinstance(headers, Mapping):
+    elif isinstance(headers, (Mapping, Headers)):
         headers = Headers(**headers)
-    elif isinstance(headers, Headers):
-        pass
     else:
         raise ValueError(
             "headers must be a list, a dict, a Headers instance or None"
